@@ -510,15 +510,15 @@ def attach_nvidia_info(report, ui=None):
     if nonfree_graphics_module() != 'nvidia':
         return
 
-    report['version.nvidia-graphics-drivers'] = package_versions("nvidia-graphics-drivers")
+    report['version.nvidia-graphics-drivers'] = package_versions("nvidia-graphics-drivers-*")
 
     for logfile in glob.glob('/proc/driver/nvidia/*'):
         if os.path.isfile(logfile):
-            attach_file(report, logfile)
+            attach_file_if_exists(report, logfile)
 
     for logfile in glob.glob('/proc/driver/nvidia/*/*'):
         if os.path.basename(logfile) != 'README':
-            attach_file(report, logfile)
+            attach_file_if_exists(report, logfile)
 
     if os.path.exists('/usr/bin/nvidia-bug-report.sh'):
         if (ui and (ui.yesno("Would you like to generate and attach an NVIDIA bug reporting file? (~/nvidia-bug-report.log.gz)") == True)):
